Development — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# Development

## Code convention

You should respect all the PEP8 convention except the rule about max line length.

## Documentation

### Build doc

In the project root folder:

    ./scripts/documentation.sh

The output is available inside docs/_build/html

## Tests

### Run tests

    py.test -v

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »